#!/usr/bin/perl -w

use strict;
use warnings;

use LWP::Simple;
use Cache::FileCache;

use vars qw($url $cache);

$url = 'http://www.imdb.com/chart/top';
$cache = new Cache::FileCache( { default_expires_in => '1h' } ); 

my $top = get_imdb_top();
$cache->set('top_250_arr', $top);

sub get_imdb_top {
	my($res);
	my $page = $cache->get('top_250');
	unless($page) {
		$page = get($url);
		$cache->set('top_250', $page);
	}

	if($page) {
		my $row;
		for(split /\n/, $page) {
			if(/Top 250 movies as voted by our users.*?\<table.*?\>(.*?)\<\/table\>/) {
				$row = $1;
				last;
			}
		}		
		
		for(split /\<\/tr\>/, $row) {
			next if m!^<tr\s+bgcolor="\#FFFFDB"!;
			my($pos, $rate, $link, $title, $year, $votes) = 
				m#^<tr.*?><td.*?>(\d+).*?<td.*?>(\d+\.?\d+).*?</td><td.*?<a href="/title/tt(\d+)/">(.*?)</a>\s+\((\d+)\).*?<td.*?>(\d+\,?\d+)#;
			push @$res, {pos => $pos, rate => $rate, code => $link, title => $title, votes => $votes, year => $year};
		}
	}

	return $res;
}
